@@ -3,7 +3,7 @@
 import os
 import fnmatch
 
-def all_file(root, patterns = '*', single_level = False, yield_folders = False):
+def all_file(root, patterns = '*', ignore_dirs = None, single_level = False, yield_folders = False):
     """
     root:            需要遍历的目录
     patterns：       需要查找的文件，以；为分割的字符串
@@ -11,7 +11,13 @@ def all_file(root, patterns = '*', single_level = False, yield_folders = False):
     yield_folders:   是否包含目录本身，默认为否
     """
     patterns = patterns.split(';')
+    if ignore_dirs: ignore_dirs = ignore_dirs.split(',')
     for path, subdirs, files in os.walk(root):
+        if ignore_dirs:
+            for dir in ignore_dirs:
+                if not dir in subdirs:
+                    continue
+                subdirs.remove(dir)
         if yield_folders:
             files.extend(subdirs)
         files.sort()
@@ -22,10 +28,12 @@ def all_file(root, patterns = '*', single_level = False, yield_folders = False):
         if single_level:
             break
 
-def clean(filter, args, logger=None):
-    path = args[0] if len(args) == 1 else '.'
+def clean(args, logger=None):
+    filter = args.filter
+    ignore_dirs = args.ignore_dirs
+    path = args.path
     for filter in filter.split(','):
-        for file in all_file(path, filter):
+        for file in all_file(path, filter, ignore_dirs):
             if logger:
                 logger.debug(file)
             else:
@@ -36,10 +44,14 @@ def clean(filter, args, logger=None):
                 pass
 
 def main():
-    from optparse import OptionParser
-    parser = OptionParser(usage="%prog [options] <path>")
-    parser.add_option('--filter', default='*.pyc',
+    from argparse import ArgumentParser
+    parser = ArgumentParser(description='Clean your files.')
+    parser.add_argument('path', default='.', nargs='?',
+                      help="clean path")
+    parser.add_argument('--filter', default='*.pyc',
                       help="fliter which file split by ,")
-    options, args = parser.parse_args()
-    clean(options.filter, args)
+    parser.add_argument('--ignore-dirs', default='',
+                      help="ignore some dirs split by ,")
+    args = parser.parse_args()
+    clean(args)
 
